@@ -78,6 +78,7 @@ use base 'Locale::Maketext';
 use Locale::Maketext::Lexicon;
 use Encode;
 
+
 Locale::Maketext::Lexicon->import(
     {
         '*'     => [ Gettext => "${LedgerSMB::Sysconfig::localepath}/*.po", ],
@@ -97,7 +98,6 @@ sub text {
 ##}
 sub date {
     my ( $self, $myconfig, $date, $longformat ) = @_;
-
     my @longmonth = (qw(Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec));
     @longmonth = (
         "January",   "February", "March",    "April",
@@ -123,8 +123,10 @@ sub date {
         return $date;
     }
     if ( $date =~ /\D/ ) {
-
-        if ( $myconfig->{dateformat} =~ /^yy/ ) {
+        if ($date  =~ /\d{4}/){ # db date in
+            ( $yy, $mm, $dd ) = split /\D/, $date;
+        }
+        elsif ( $myconfig->{dateformat} =~ /^yy/ ) {
             ( $yy, $mm, $dd ) = split /\D/, $date;
         }
         elsif ( $myconfig->{dateformat} =~ /^mm/ ) {
