@@ -80,7 +80,7 @@ my @default_textboxes = (
 my @default_others = qw(businessnumber weightunit separate_duties default_language
                         inventory_accno_id income_accno_id expense_accno_id 
                         fxgain_accno_id fxloss_accno_id default_country 
-                        templates curr);
+                        templates curr template_images);
 
 sub save_as_new {
 
@@ -185,15 +185,16 @@ sub list_account {
 "$form->{script}?action=list_account&path=$form->{path}&login=$form->{login}&sessionid=$form->{sessionid}";
 
     $form->{callback} = $callback;
-    @column_index = qw(accno gifi_accno description debit credit link);
+    @column_index = qw(accno gifi_accno description debit credit link delete);
 
     my $column_names = {
-        accno => 'Account',
-        gifi_accno => 'GIFI',
-        description => 'Description',
-        debit => 'Debit',
-        credit => 'Credit',
-        link => 'Link'
+        accno => $locale->text('Account'),
+        gifi_accno => $locale->text('GIFI'),
+        description => $locale->text('Description'),
+        debit => $locale->text('Debit'),
+        credit => $locale->text('Credit'),
+        link => $locale->text('Link'),
+        delete => $locale->text('Delete')
     };
 
     # escape callback
@@ -246,6 +247,11 @@ sub list_account {
             $column_data{description} = $ca->{description};
             $column_data{debit}       = $ca->{debit};
             $column_data{credit} = $ca->{credit};
+            if ($ca->{rowcount} == 0){
+                $column_data{delete} ={text => '['.$locale->text('Delete').']',
+                                      href => 'am.pl?action=delete_account&'.
+                                              'id='.$ca->{id} };
+            }
 	    $column_data{link}   = {text => $ca->{link}, delimiter => ':'};
 
         }
@@ -254,11 +260,10 @@ sub list_account {
 
     my %can_load;
     $can_load{CSV} = 1;
-    $can_load{XLS} = ! eval { require Excel::Template::Plus };
-    $can_load{ODS} = ! eval { require OpenOffice::OODoc };
+    $can_load{ODS} = eval { require OpenOffice::OODoc };
 
     my @buttons;
-    for my $type (qw(CSV XLS ODS)) {
+    for my $type (qw(CSV ODS)) {
         push @buttons, {
             name => 'action',
             value => lc "${type}_list_account",
@@ -1508,6 +1513,9 @@ sub taxes {
     $i = 0;
     foreach $ref ( @{ $form->{taxrates} } ) {
         $i++;
+        $form->{"minvalue_$i"} = 
+          $form->format_amount( \%myconfig, $ref->{minvalue}) || 0;
+        
         $form->{"taxrate_$i"} =
           $form->format_amount( \%myconfig, $ref->{rate} );
         $form->{"taxdescription_$i"} = $ref->{description};
