@@ -274,7 +274,7 @@ WITH INHERIT NOLOGIN
 IN ROLE "lsmb_<?lsmb dbname ?>__ar_transaction_create";
 
 --### oldcode: UPDATE granted because old code wants it
-GRANT SELECT, INSERT, UPDATE ON invoice, new_shipto 
+GRANT SELECT, INSERT, UPDATE ON invoice, new_shipto, new_shipto_id_seq
 TO "lsmb_<?lsmb dbname ?>__ar_invoice_create";
 GRANT ALL ON invoice_id_seq TO "lsmb_<?lsmb dbname ?>__ar_invoice_create";
 GRANT INSERT ON inventory TO "lsmb_<?lsmb dbname ?>__ar_invoice_create";
@@ -626,68 +626,6 @@ IN ROLE "lsmb_<?lsmb dbname ?>__ap_all_vouchers",
 "lsmb_<?lsmb dbname ?>__purchase_order_list",
 "lsmb_<?lsmb dbname ?>__rfq_list";
 
--- POS
-CREATE ROLE "lsmb_<?lsmb dbname ?>__pos_enter"
-WITH INHERIT NOLOGIN
-IN ROLE "lsmb_<?lsmb dbname ?>__contact_read";
-
-GRANT "lsmb_<?lsmb dbname ?>__ar_transaction_create" TO "lsmb_<?lsmb dbname ?>__pos_enter";
-
-GRANT SELECT, INSERT ON invoice TO "lsmb_<?lsmb dbname ?>__pos_enter";
-GRANT INSERT ON inventory TO "lsmb_<?lsmb dbname ?>__pos_enter";
-GRANT SELECT, INSERT ON ar TO "lsmb_<?lsmb dbname ?>__pos_enter";
-GRANT SELECT ON oe TO "lsmb_<?lsmb dbname ?>__pos_enter";
-GRANT INSERT ON acc_trans TO "lsmb_<?lsmb dbname ?>__pos_enter";
-GRANT ALL ON id TO "lsmb_<?lsmb dbname ?>__pos_enter";
-GRANT ALL ON acc_trans_entry_id_seq TO "lsmb_<?lsmb dbname ?>__pos_enter";
-GRANT ALL ON invoice_id_seq TO "lsmb_<?lsmb dbname ?>__pos_enter";
-GRANT ALL ON inventory_entry_id_seq TO "lsmb_<?lsmb dbname ?>__pos_enter";
-GRANT SELECT ON oe TO "lsmb_<?lsmb dbname ?>__pos_enter";
-
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (16, 'allow', 'lsmb_<?lsmb dbname ?>__pos_enter');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (17, 'allow', 'lsmb_<?lsmb dbname ?>__pos_enter');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (18, 'allow', 'lsmb_<?lsmb dbname ?>__pos_enter');
-
-
-CREATE ROLE "lsmb_<?lsmb dbname ?>__close_till"
-WITH INHERIT NOLOGIN;
-
-GRANT INSERT ON gl TO "lsmb_<?lsmb dbname ?>__close_till";
-GRANT INSERT ON acc_trans TO "lsmb_<?lsmb dbname ?>__close_till";
-GRANT ALL ON id TO "lsmb_<?lsmb dbname ?>__close_till";
-GRANT ALL ON acc_trans_entry_id_seq TO "lsmb_<?lsmb dbname ?>__close_till";
-
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (16, 'allow', 'lsmb_<?lsmb dbname ?>__close_till');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (20, 'allow', 'lsmb_<?lsmb dbname ?>__close_till');
-
-
-CREATE ROLE "lsmb_<?lsmb dbname ?>__list_all_open"
-WITH INHERIT NOLOGIN;
-
-GRANT SELECT ON ar TO "lsmb_<?lsmb dbname ?>__list_all_open";
-GRANT SELECT ON acc_trans TO "lsmb_<?lsmb dbname ?>__list_all_open";
-
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (16, 'allow', 'lsmb_<?lsmb dbname ?>__list_all_open');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (18, 'allow', 'lsmb_<?lsmb dbname ?>__list_all_open');
-
-
-CREATE ROLE "lsmb_<?lsmb dbname ?>__pos_cashier"
-WITH INHERIT NOLOGIN
-IN ROLE "lsmb_<?lsmb dbname ?>__pos_enter",
-"lsmb_<?lsmb dbname ?>__close_till";
-
-CREATE ROLE "lsmb_<?lsmb dbname ?>__pos_all"
-WITH INHERIT NOLOGIN
-IN ROLE "lsmb_<?lsmb dbname ?>__pos_cashier",
-"lsmb_<?lsmb dbname ?>__list_all_open";
-
 -- CASH
 CREATE ROLE "lsmb_<?lsmb dbname ?>__reconciliation_enter"
 WITH INHERIT NOLOGIN;
@@ -833,6 +771,9 @@ WITH INHERIT NOLOGIN;
 
 GRANT "lsmb_<?lsmb dbname ?>__file_read" TO "lsmb_<?lsmb dbname ?>__part_edit";
 
+GRANT ALL ON partscustomer_entry_id_seq 
+TO "lsmb_<?lsmb dbname ?>__contact_edit", "lsmb_<?lsmb dbname ?>__part_edit";
+
 GRANT SELECT ON assembly, orderitems, jcitems, invoice 
 TO "lsmb_<?lsmb dbname ?>__part_edit";
 
